summaryrefslogtreecommitdiffstats
path: root/gnu/usr.bin/patch/common.h
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/usr.bin/patch/common.h')
-rw-r--r--gnu/usr.bin/patch/common.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/gnu/usr.bin/patch/common.h b/gnu/usr.bin/patch/common.h
index ed97132..7063be6 100644
--- a/gnu/usr.bin/patch/common.h
+++ b/gnu/usr.bin/patch/common.h
@@ -63,7 +63,7 @@
#define MAXHUNKSIZE 200000 /* is this enough lines? */
#define INITHUNKMAX 125 /* initial dynamic allocation size */
-#define MAXLINELEN 4096
+#define INITLINELEN 4096
#define BUFFERSIZE 4096
#define SCCSPREFIX "s."
@@ -105,7 +105,8 @@ EXT int optind_last; /* for restarting plan_b */
EXT struct stat filestat; /* file statistics area */
EXT int filemode INIT(0644);
-EXT char buf[MAXLINELEN]; /* general purpose buffer */
+EXT char *buf; /* general purpose buffer */
+EXT size_t buf_size; /* size of the general purpose buffer */
EXT FILE *ofp INIT(Nullfp); /* output file pointer */
EXT FILE *rejfp INIT(Nullfp); /* reject file pointer */
OpenPOWER on IntegriCloud